@@ -1,11 +1,80 @@
 # %%
 import bnlearn as bn
-print(bn.__version__)
-print(dir(bn))
+# print(bn.__version__)
+# print(dir(bn))
 
-print(dir(bn.structure_learning))
-print(dir(bn.parameter_learning))
-print(dir(bn.inference))
+# print(dir(bn.structure_learning))
+# print(dir(bn.parameter_learning))
+# print(dir(bn.inference))
+
+
+# %% Naive Bayesian model
+import bnlearn as bn
+df = bn.import_example('random')
+
+# Structure learning
+model = bn.structure_learning.fit(df, methodtype='naivebayes', root_node="B")
+# Plot
+bn.plot(model)
+
+
+# %% Naive Bayesian model
+import bnlearn as bn
+from pgmpy.factors.discrete import TabularCPD
+
+edges = [('A', 'B'), ('A', 'C'), ('A', 'D')]
+DAG = bn.make_DAG(edges, methodtype='naivebayes')
+bn.plot(DAG);
+
+cpd_A = TabularCPD(variable='A', variable_card=3, values=[[0.3], [0.5], [0.2]])
+print(cpd_A)
+cpd_B = TabularCPD(variable='B', variable_card=2, values=[[0.4, 0.9], [0.6, 0.1]], evidence=['A'], evidence_card=[2])
+print(cpd_B)
+cpd_C = TabularCPD(variable='C', variable_card=2, values=[[0.4, 0.9], [0.6, 0.1]], evidence=['A'], evidence_card=[2])
+print(cpd_C)
+cpd_D = TabularCPD(variable='D', variable_card=2, values=[[0.4, 0.9], [0.6, 0.1]], evidence=['A'], evidence_card=[2])
+print(cpd_D)
+
+DAG = bn.make_DAG(DAG, CPD=[cpd_A, cpd_B, cpd_C, cpd_D], checkmodel=True)
+bn.print_CPD(DAG, checkmodel=True)
+
+# %% Adjust some edge properties
+
+import bnlearn as bn
+# Load asia DAG
+df = bn.import_example(data='asia')
+# Structure learning of sampled dataset
+model = bn.structure_learning.fit(df)
+# plot static
+G = bn.plot(model)
+
+# Set some edge properties
+edge_properties = bn.get_edge_properties(model)
+edge_properties['either', 'xray']['color']='#8A0707'
+edge_properties['either', 'xray']['weight']=4
+edge_properties['bronc', 'dysp']['weight']=10
+edge_properties['bronc', 'dysp']['color']='#8A0707'
+
+# Set some node properties
+node_properties = bn.get_node_properties(model)
+node_properties['xray']['node_color']='#8A0707'
+node_properties['xray']['node_size']=20
+
+# Plot
+params_static={'edge_alpha':0.6, 'arrowstyle':'->', 'arrowsize':60}
+bn.plot(model, interactive=False, node_properties=node_properties, edge_properties=edge_properties, params_static=params_static)
+# bn.plot(model, interactive=True, node_properties=node_properties, edge_properties=edge_properties, params_static=params_static);
+
+# %% TAN : Tree-augmented Naive Bayes (TAN)
+# https://pgmpy.org/examples/Structure%20Learning%20with%20TAN.html
+# https://pgmpy.org/models/naive.html
+import bnlearn as bn
+
+df = bn.import_example()
+# Structure learning
+model = bn.structure_learning.fit(df, methodtype='tan', root_node='Cloudy', class_node='Rain', verbose=0)
+bn.plot(model)
+bn.plot(model, interactive=True, node_size=10)
 
 
 # %% Coloring networks
@@ -215,12 +284,13 @@ import bnlearn as bn
 
 df = bn.import_example('asia')
 edges = [('smoke', 'lung'),
-         ('smoke', 'bronc'),
-         ('lung', 'xray'),
-         ('bronc', 'xray')]
+          ('smoke', 'bronc'),
+          ('lung', 'xray'),
+          ('bronc', 'xray')]
+
 
 # Make the actual Bayesian DAG
-DAG = bn.make_DAG(edges, verbose=0)
+DAG = bn.make_DAG(edges, verbose=0, methodtype='bayes')
 model = bn.parameter_learning.fit(DAG, df, verbose=3)
 # Generate some data based on DAG
 df = bn.sampling(model, n=1000)
